==> flyway-core-11.17.0-sources.jar: org/flywaydb/core/extensibility/ConfigurationParameter.java <==
/*-
 * ========================LICENSE_START=================================
 * flyway-core
 * ========================================================================
 * Copyright (C) 2010 - 2025 Red Gate Software Ltd
 * ========================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */
package org.flywaydb.core.extensibility;

import java.util.Collections;
import java.util.List;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

@Getter
@RequiredArgsConstructor
public class ConfigurationParameter {
    public final String name;
    public final String description;
    public final boolean required;

    // Certain configuration parameters apply only to specific sub-commands of a command operation
    public final List<String> parentSubCommands;

    public ConfigurationParameter(String name, String description, boolean required) {
        this(name, description, required, Collections.emptyList());
    }
}

==> flyway-core-11.19.1-sources.jar: org/flywaydb/core/extensibility/ConfigurationParameter.java <==
/*-
 * ========================LICENSE_START=================================
 * flyway-core
 * ========================================================================
 * Copyright (C) 2010 - 2025 Red Gate Software Ltd
 * ========================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */
package org.flywaydb.core.extensibility;

import java.util.Collections;
import java.util.List;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

@Getter
@EqualsAndHashCode(onlyExplicitlyIncluded = true)
@RequiredArgsConstructor
public class ConfigurationParameter {
    @EqualsAndHashCode.Include
    public final String name;
    public final String description;
    public final boolean required;

    // Certain configuration parameters apply only to specific sub-commands of a command operation
    public final List<String> parentSubCommands;

    public ConfigurationParameter(final String name, final String description, final boolean required) {
        this(name, description, required, Collections.emptyList());
    }
}
